@@ -72,9 +72,11 @@
 #include "peripherals/disk/fdd.h"
 #include "peripherals/fuller.h"
 #include "peripherals/ide/divide.h"
+#include "peripherals/ide/divmmc.h"
 #include "peripherals/ide/simpleide.h"
 #include "peripherals/ide/zxatasp.h"
 #include "peripherals/ide/zxcf.h"
+#include "peripherals/ide/zxmmc.h"
 #include "peripherals/joystick.h"
 #include "peripherals/if1.h"
 #include "peripherals/if2.h"
@@ -87,6 +89,7 @@
 #include "peripherals/spectranet.h"
 #include "peripherals/ula.h"
 #include "peripherals/usource.h"
+#include "phantom_typist.h"
 #include "pokefinder/pokemem.h"
 #include "profile.h"
 #include "psg.h"
@@ -141,6 +144,8 @@ typedef struct start_files_t {
   const char *zxatasp_master, *zxatasp_slave;
   const char *zxcf;
   const char *divide_master, *divide_slave;
+  const char *divmmc;
+  const char *zxmmc;
   const char *mdr[8];
 
 } start_files_t;
@@ -194,13 +199,12 @@ int main(int argc, char **argv)
       z80_do_opcodes();
       event_do_events();
     }
-    r = 0;
+    r = debugger_get_exit_code();
   }
 
   fuse_end();
   
   return r;
-
 }
 
 static int
@@ -297,6 +301,7 @@ run_startup_manager( int *argc, char ***argv )
   disciple_register_startup();
   display_register_startup( &display_context );
   divide_register_startup();
+  divmmc_register_startup();
   event_register_startup();
   fdd_register_startup();
   fuller_register_startup();
@@ -314,6 +319,7 @@ run_startup_manager( int *argc, char ***argv )
   mempool_register_startup();
   multiface_register_startup();
   opus_register_startup();
+  phantom_typist_register_startup();
   plusd_register_startup();
   printer_register_startup();
   profile_register_startup();
@@ -336,6 +342,7 @@ run_startup_manager( int *argc, char ***argv )
   z80_register_startup();
   zxatasp_register_startup();
   zxcf_register_startup();
+  zxmmc_register_startup();
 
   return startup_manager_run();
 }
@@ -406,7 +413,7 @@ creator_init( void *context )
 {
   size_t i;
   unsigned int version[4] = { 0, 0, 0, 0 };
-  char *custom, osname[ 256 ];
+  char *custom, osname[ 192 ];
   static const size_t CUSTOM_SIZE = 256;
   
   libspectrum_error error; int sys_error;
@@ -597,6 +604,11 @@ setup_start_files( start_files_t *start_files )
   start_files->divide_slave =
     utils_safe_strdup( settings_current.divide_slave_file );
 
+  start_files->divmmc =
+    utils_safe_strdup( settings_current.divmmc_file );
+
+  start_files->zxmmc = utils_safe_strdup( settings_current.zxmmc_file );
+
   start_files->mdr[0] = settings_current.mdr_file;
   start_files->mdr[1] = settings_current.mdr_file2;
   start_files->mdr[2] = settings_current.mdr_file3;
@@ -657,6 +669,10 @@ parse_nonoption_args( int argc, char **argv, int first_arg,
 	start_files->simpleide_master = filename;
       } else if( settings_current.divide_enabled ) {
 	start_files->divide_master = filename;
+      } else if( settings_current.divmmc_enabled ) {
+	start_files->divmmc = filename;
+      } else if( settings_current.zxmmc_enabled ) {
+	start_files->zxmmc = filename;
       } else {
 	/* No IDE interface active, so activate the ZXCF */
 	settings_current.zxcf_active = 1;
@@ -901,6 +917,16 @@ do_start_files( start_files_t *start_files )
     if( error ) return error;
   }
 
+  if( start_files->divmmc ) {
+    error = divmmc_insert( start_files->divmmc );
+    if( error ) return error;
+  }
+
+  if( start_files->zxmmc ) {
+    error = zxmmc_insert( start_files->zxmmc );
+    if( error ) return error;
+  }
+
   /* Input recordings */
 
   if( start_files->playback ) {
