@@ -5,8 +5,6 @@
 #			  Fredrick Meunier, Catalin Mihaila, Stuart Brady
 # Copyright (c) 2015 Sergio Baldoví
 
-# $Id: keysyms.pl 5434 2016-05-01 04:22:45Z fredm $
-
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -157,9 +155,10 @@ my %ui_data = (
     	    },
 
     sdl  => { headers => [ 'SDL.h' ],
-	      max_length => 15,
+	      max_length => 18,
 	      skips => { map { $_ => 1 } ( 'Hyper_L','Hyper_R','Caps_Lock',
-                         'A' .. 'Z', 'bar', 'dead_circumflex' ) },
+                         'A' .. 'Z', 'asciitilde', 'bar', 'dead_circumflex',
+                         'braceleft', 'braceright', 'percent' ) },
 	      unicode_skips => { map { $_ => 1 } qw( Hyper_L Hyper_R Caps_Lock
                          Escape F1 F2 F3 F4 F5 F6 F7 F8 F9 F10 F11 F12
                          BackSpace Tab Caps_Lock Return Shift_L Shift_R
@@ -170,6 +169,8 @@ my %ui_data = (
 	      translations => {
 		  apostrophe  => 'QUOTE',
 		  asciicircum => 'CARET',
+		  bracketleft => 'LEFTBRACKET',
+		  bracketright => 'RIGHTBRACKET',
 		  exclam      => 'EXCLAIM',
 		  Control_L   => 'LCTRL',	 
 		  Control_R   => 'RCTRL',	 
@@ -188,8 +189,18 @@ my %ui_data = (
                   numbersign  => '#',
                   ampersand   => "&",
                   apostrophe  => "'",
+                  asciitilde  => "~",
+                  at          => "@",
+                  backslash   => "\\\\",
+                  braceleft   => "{",
+                  braceright  => "}",
+                  bracketleft => "[",
+                  bracketright => "]",
                   parenleft   => "(",
                   parenright  => ")",
+                  percent     => "%",
+                  question    => "?",
+                  quotedbl    => '\\"',
                   asterisk    => "*",
                   plus        => "+",
                   comma       => ',',
@@ -203,6 +214,7 @@ my %ui_data = (
                   greater     => '>',
                   asciicircum => '^',
                   bar         => '|',
+                  underscore  => '_',
 	      },
 	      function => \&sdl_keysym,
 	      unicode_function => \&sdl_unicode_keysym,
@@ -244,18 +256,14 @@ my %ui_data = (
 					   'dollar','less','greater','exclam',
 					   'ampersand','parenleft','parenright',
 					   'asterisk','plus','colon','bar',
-					   'asciicircum','dead_circumflex',
+					   'braceleft','braceright','bracketleft','bracketright',
+					   'apostrophe','asciicircum','dead_circumflex','asciitilde',
+					   'at','backslash','comma','equal','minus','numbersign',
+					   'percent','period','question','quotedbl',
+					   'semicolon','slash','underscore',
 					   'A' .. 'Z' ) },
 	      translations => { 
-		  numbersign  => 'OEM_5',
-		  apostrophe  => 'OEM_7',
-		  comma       => 'OEM_COMMA',
-		  minus       => 'OEM_MINUS',
-		  period      => 'OEM_PERIOD',
-		  slash       => 'OEM_2',
 		  BackSpace   => 'BACK',
-		  semicolon   => 'OEM_1',
-		  equal       => 'OEM_PLUS',
 		  Page_Up     => 'PRIOR',
 		  Page_Down   => 'NEXT',
 		  Caps_Lock   => 'CAPITAL',
@@ -324,20 +332,6 @@ CODE
 
 # Comment to unbreak Emacs' perl mode
 
-if ( $ui eq 'win32' ) {
-    # To allow VK_OEM_{COMMA,MINUS,PERIOD,PLUS} to be used, we must
-    # define WINVER to be >= 0x0500 before we include <windows.h>
-    # But instead of requiring Windows 2000 or later, it's better to
-    # define the missing values
-    print "#if ! (_WIN32_WINNT >= 0x0500)\n"
-        . "#define VK_OEM_PLUS     0xBB\n"
-        . "#define VK_OEM_COMMA    0xBC\n"
-        . "#define VK_OEM_MINUS    0xBD\n"
-        . "#define VK_OEM_PERIOD   0xBE\n"
-        . "#endif\n"
-        . "\n";
-}
-
 print << "CODE";
 
 #include "input.h"
@@ -376,13 +370,13 @@ foreach( @keys ) {
 	for( my $i = 0; $i <= $#cooked_keysyms; $i++ ) {
 	    next unless defined $cooked_keysyms[$i] and
 			$cooked_keysyms[$i] eq $ui_keysym;
-	    printf "  { %3i, INPUT_KEY_%-11s },\n", $i, $keysym;
+	    printf "  { %3i, INPUT_KEY_%-12s },\n", $i, $keysym;
 	    last;
 	}
 
     } else {
 
-	printf "  { %-$ui_data{$ui}{max_length}s INPUT_KEY_%-11s },\n",
+	printf "  { %-$ui_data{$ui}{max_length}s INPUT_KEY_%-12s },\n",
             "$ui_keysym,", $keysym;
 
     }
@@ -418,7 +412,7 @@ print "\nkeysyms_map_t unicode_keysyms_map[] = {\n\n";
 
         $ui_keysym = $ui_data{$ui}{unicode_function}->( $ui_keysym );
 
-	printf "  { %-$ui_data{$ui}{max_length}s INPUT_KEY_%-11s },\n",
+	printf "  { %-$ui_data{$ui}{max_length}s INPUT_KEY_%-12s },\n",
             "$ui_keysym,", $keysym;
 
     }
@@ -431,3 +425,46 @@ print << "CODE";
 
 CODE
 }
+
+if( $ui eq 'win32' ) {
+
+print << "CODE";
+keysyms_map_t oem_keysyms_map[] = {
+
+  { '&',             INPUT_KEY_ampersand    },
+  { '\\'',            INPUT_KEY_apostrophe   },
+  { '~',             INPUT_KEY_asciitilde   },
+  { '*',             INPUT_KEY_asterisk     },
+  { '\@',             INPUT_KEY_at           },
+  { '\\\\',            INPUT_KEY_backslash    },
+  { '|',             INPUT_KEY_bar          },
+  { '{',             INPUT_KEY_braceleft    },
+  { '}',             INPUT_KEY_braceright   },
+  { '[',             INPUT_KEY_bracketleft  },
+  { ']',             INPUT_KEY_bracketright },
+  { ':',             INPUT_KEY_colon        },
+  { ',',             INPUT_KEY_comma        },
+  { '\$',             INPUT_KEY_dollar       },
+  { '=',             INPUT_KEY_equal        },
+  { '!',             INPUT_KEY_exclam       },
+  { '>',             INPUT_KEY_greater      },
+  { '<',             INPUT_KEY_less         },
+  { '-',             INPUT_KEY_minus        },
+  { '#',             INPUT_KEY_numbersign   },
+  { '(',             INPUT_KEY_parenleft    },
+  { ')',             INPUT_KEY_parenright   },
+  { '%',             INPUT_KEY_percent      },
+  { '.',             INPUT_KEY_period       },
+  { '+',             INPUT_KEY_plus         },
+  { '?',             INPUT_KEY_question     },
+  { '"',             INPUT_KEY_quotedbl     },
+  { ';',             INPUT_KEY_semicolon    },
+  { '/',             INPUT_KEY_slash        },
+  { '_',             INPUT_KEY_underscore   },
+
+  { 0, 0 }			/* End marker: DO NOT MOVE! */
+
+};
+
+CODE
+}
