@@ -113,10 +113,6 @@ MENU_CALLBACK_WITH_ACTION( menu_media_ide_insert );
 MENU_CALLBACK_WITH_ACTION( menu_media_ide_commit );
 MENU_CALLBACK_WITH_ACTION( menu_media_ide_eject );
 
-MENU_CALLBACK( menu_media_ide_zxatasp_upload );
-MENU_CALLBACK( menu_media_ide_zxatasp_writeprotect );
-MENU_CALLBACK( menu_media_ide_zxcf_upload );
-
 /*
  * Things to be defined elsewhere
  */
