@@ -1,9 +1,7 @@
 /* joystick.c: Joystick emulation support
-   Copyright (c) 2001-2011 Russell Marks, Darren Salt, Philip Kendall
+   Copyright (c) 2001-2016 Russell Marks, Darren Salt, Philip Kendall
    Copyright (c) 2015 Stuart Brady
 
-   $Id: joystick.c 5677 2016-07-09 13:58:02Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -29,6 +27,7 @@
 #include <libspectrum.h>
 
 #include "fuse.h"
+#include "infrastructure/startup_manager.h"
 #include "joystick.h"
 #include "keyboard.h"
 #include "module.h"
@@ -124,8 +123,8 @@ static const periph_t kempston_loose_periph = {
 
 /* Init/shutdown functions. Errors aren't important here */
 
-void
-fuse_joystick_init (void)
+int
+joystick_init( void *context )
 {
   joysticks_supported = ui_joystick_init();
   kempston_value = timex1_value = timex2_value = 0x00;
@@ -134,14 +133,28 @@ fuse_joystick_init (void)
   module_register( &joystick_module_info );
   periph_register( PERIPH_TYPE_KEMPSTON, &kempston_strict_periph );
   periph_register( PERIPH_TYPE_KEMPSTON_LOOSE, &kempston_loose_periph );
+
+  return 0;
 }
 
 void
-fuse_joystick_end (void)
+joystick_end( void )
 {
   ui_joystick_end();
 }
 
+void
+joystick_register_startup( void )
+{
+  startup_manager_module dependencies[] = {
+    STARTUP_MANAGER_MODULE_LIBSPECTRUM,
+    STARTUP_MANAGER_MODULE_SETUID
+  };
+  startup_manager_register( STARTUP_MANAGER_MODULE_JOYSTICK, dependencies,
+                            ARRAY_SIZE( dependencies ), joystick_init,
+                            joystick_end, NULL );
+}
+
 int
 joystick_press( int which, joystick_button button, int press )
 {
