@@ -38,6 +38,9 @@ int screenshot_available_scalers( scaler_type scaler );
 int screenshot_scr_write( const char *filename );
 int screenshot_scr_read( const char *filename );
 
+int screenshot_mlt_write( const char *filename );
+int screenshot_mlt_read( const char *filename );
+
 #define STANDARD_SCR_SIZE 6912
 
 #endif				/* #ifndef FUSE_SCREENSHOT_H */
