@@ -631,6 +631,18 @@ static const struct menu_item_entries menu_item_lookup[] = {
     "/Media/IDE/DivIDE/Slave/Commit",
     "/Media/IDE/DivIDE/Slave/Eject", 0 },
 
+  { UI_MENU_ITEM_MEDIA_IDE_DIVMMC, "/Media/IDE/DivMMC" },
+
+  { UI_MENU_ITEM_MEDIA_IDE_DIVMMC_EJECT,
+    "/Media/IDE/DivMMC/Commit",
+    "/Media/IDE/DivMMC/Eject", 0 },
+
+  { UI_MENU_ITEM_MEDIA_IDE_ZXMMC, "/Media/IDE/ZXMMC" },
+
+  { UI_MENU_ITEM_MEDIA_IDE_ZXMMC_EJECT,
+    "/Media/IDE/ZXMMC/Commit",
+    "/Media/IDE/ZXMMC/Eject", 0 },
+
   { UI_MENU_ITEM_RECORDING,
     "/File/Recording/Stop", 
     "/File/Recording/Record...", 1,
