@@ -256,7 +256,7 @@ load_data( GtkEntry *entry GCC_UNUSED, gpointer user_data )
   }
 
   for( i = 0; i < length; i++ )
-    writebyte( start + i, info->file.buffer[ i ] );
+    writebyte_internal( start + i, info->file.buffer[ i ] );
 
   gtkui_destroy_widget_and_quit( info->dialog, NULL );
 }
@@ -308,8 +308,7 @@ save_data( GtkEntry *entry GCC_UNUSED, gpointer user_data )
 {
   struct binary_info *info = user_data;
 
-  long start, length; size_t i;
-  libspectrum_byte *buffer;
+  long start, length;
   const gchar *nptr;
   char *endptr;
   int base;
@@ -326,12 +325,6 @@ save_data( GtkEntry *entry GCC_UNUSED, gpointer user_data )
     return;
   }
 
-  buffer = malloc( length * sizeof( libspectrum_byte ) );
-  if( !buffer ) {
-    ui_error( UI_ERROR_ERROR, "out of memory at %s:%d", __FILE__, __LINE__ );
-    return;
-  }
-
   errno = 0;
   nptr = gtk_entry_get_text( GTK_ENTRY( info->start_widget ) );
   base = ( g_str_has_prefix( nptr, "0x" ) )? 16 : 10;
@@ -339,23 +332,16 @@ save_data( GtkEntry *entry GCC_UNUSED, gpointer user_data )
 
   if( errno || start < 0 || start > 0xffff || endptr == nptr ) {
     ui_error( UI_ERROR_ERROR, "Start must be between 0 and 65535" );
-    free( buffer );
     return;
   }
 
   if( start + length > 0x10000 ) {
     ui_error( UI_ERROR_ERROR, "Block ends after address 65535" );
-    free( buffer );
     return;
   }
 
-  for( i = 0; i < length; i++ )
-    buffer[ i ] = readbyte( start + i );
-
-  error = utils_write_file( info->filename, buffer, length );
-  if( error ) { free( buffer ); return; }
-
-  free( buffer );
+  error = utils_save_binary( start, length, info->filename );
+  if( error ) return;
 
   gtkui_destroy_widget_and_quit( info->dialog, NULL );
 }
