@@ -121,11 +121,11 @@ static void toggle_display_disassembly( GtkToggleAction* action,
                                         gpointer data );
 static void toggle_display_stack( GtkToggleAction* action, gpointer data );
 static void toggle_display_events( GtkToggleAction* action, gpointer data );
-static int create_register_display( GtkBox *parent, gtkui_font font );
+static int create_register_display( GtkBox *parent, PangoFontDescription *font );
 static int create_memory_map( GtkBox *parent );
 static void create_breakpoints( GtkBox *parent );
-static void create_disassembly( GtkBox *parent, gtkui_font font );
-static void create_stack_display( GtkBox *parent, gtkui_font font );
+static void create_disassembly( GtkBox *parent, PangoFontDescription *font );
+static void create_stack_display( GtkBox *parent, PangoFontDescription *font );
 static void stack_activate( GtkTreeView *tree_view, GtkTreePath *path,
 			    GtkTreeViewColumn *column, gpointer user_data );
 static void create_events( GtkBox *parent );
@@ -357,7 +357,7 @@ create_dialog( void )
   GtkWidget *hbox, *vbox, *hbox2, *content_area;
   GtkAccelGroup *accel_group;
 
-  gtkui_font font;
+  PangoFontDescription *font;
 
   error = gtkui_get_monospaced_font( &font ); if( error ) return error;
 
@@ -500,7 +500,7 @@ toggle_display_events( GtkToggleAction* action, gpointer data GCC_UNUSED )
 }
 
 static int
-create_register_display( GtkBox *parent, gtkui_font font )
+create_register_display( GtkBox *parent, PangoFontDescription *font )
 {
   size_t i;
 
@@ -519,8 +519,16 @@ create_register_display( GtkBox *parent, gtkui_font font )
   gtk_box_pack_start( parent, register_display, FALSE, FALSE, 0 );
 
   for( i = 0; i < 18; i++ ) {
+    PangoAttrList *list;
+    PangoAttribute *attr;
+
     registers[i] = gtk_label_new( "" );
-    gtkui_set_font( registers[i], font );
+
+    list = pango_attr_list_new();
+    attr = pango_attr_font_desc_new( font );
+    pango_attr_list_insert( list, attr );
+    gtk_label_set_attributes( GTK_LABEL( registers[i] ), list );
+    pango_attr_list_unref( list );
 
 #if GTK_CHECK_VERSION( 3, 0, 0 )
     gtk_grid_attach( GTK_GRID( register_display ), registers[i],
@@ -601,7 +609,7 @@ create_breakpoints( GtkBox *parent )
 }
 
 static void
-create_disassembly( GtkBox *parent, gtkui_font font )
+create_disassembly( GtkBox *parent, PangoFontDescription *font )
 {
   size_t i;
 
@@ -649,7 +657,7 @@ create_disassembly( GtkBox *parent, gtkui_font font )
 }
 
 static void
-create_stack_display( GtkBox *parent, gtkui_font font )
+create_stack_display( GtkBox *parent, PangoFontDescription *font )
 {
   size_t i;
   static const gchar *const titles[] = { "Address", "Instruction" };
@@ -775,9 +783,9 @@ static int
 create_buttons( GtkDialog *parent, GtkAccelGroup *accel_group )
 {
   static const gtkstock_button
-    step  = { "Single step", G_CALLBACK( gtkui_debugger_done_step ), NULL, NULL, 0, 0, 0, 0 },
-    cont  = { "Continue", G_CALLBACK( gtkui_debugger_done_continue ), NULL, NULL, 0, 0, 0, 0 },
-    brk   = { "Break", G_CALLBACK( gtkui_debugger_break ), NULL, NULL, 0, 0, 0, 0 };
+    step  = { "Single step", G_CALLBACK( gtkui_debugger_done_step ), NULL, NULL, 0, 0, 0, 0, GTK_RESPONSE_NONE },
+    cont  = { "Continue", G_CALLBACK( gtkui_debugger_done_continue ), NULL, NULL, 0, 0, 0, 0, GTK_RESPONSE_NONE },
+    brk   = { "Break", G_CALLBACK( gtkui_debugger_break ), NULL, NULL, 0, 0, 0, 0, GTK_RESPONSE_NONE };
 
   /* Create the action buttons for the dialog box */
   gtkstock_create_button( GTK_WIDGET( parent ), accel_group, &step );
