@@ -29,6 +29,10 @@
 
 #include <gtk/gtk.h>
 
+#ifdef GDK_WINDOWING_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
+
 #include "display.h"
 #include "fuse.h"
 #include "gtkinternals.h"
@@ -235,6 +239,26 @@ uidisplay_init( int width, int height )
   return 0;
 }
 
+/* Ensure that an appropriate Cairo surface exists */
+static void
+ensure_appropriate_surface( void )
+{
+#if GTK_CHECK_VERSION( 3, 0, 0 )
+
+  /* Create a bigger surface for the new display size */
+  float scale = (float)gtkdisplay_current_size / image_scale;
+  if( surface ) cairo_surface_destroy( surface );
+
+  surface =
+      cairo_image_surface_create_for_data( scaled_image,
+                                           CAIRO_FORMAT_RGB24,
+                                           scale * image_width,
+                                           scale * image_height,
+                                           scaled_pitch );
+
+#endif                /* #if GTK_CHECK_VERSION( 3, 0, 0 ) */
+}
+
 static int
 drawing_area_resize( int width, int height, int force_scaler )
 {
@@ -253,20 +277,7 @@ drawing_area_resize( int width, int height, int force_scaler )
 
   memset( scaled_image, 0, sizeof( scaled_image ) );
 
-#if GTK_CHECK_VERSION( 3, 0, 0 )
-
-  /* Create a bigger surface for the new display size */
-  float scale = (float)gtkdisplay_current_size / image_scale;
-  if( surface ) cairo_surface_destroy( surface );
-
-  surface =
-      cairo_image_surface_create_for_data( scaled_image,
-                                           CAIRO_FORMAT_RGB24,
-                                           scale * image_width,
-                                           scale * image_height,
-                                           scaled_pitch );
-
-#endif                /* #if GTK_CHECK_VERSION( 3, 0, 0 ) */
+  ensure_appropriate_surface();
 
   display_refresh_all();
 
@@ -538,16 +549,7 @@ static gboolean
 gtkdisplay_draw( GtkWidget *widget, cairo_t *cr, gpointer user_data )
 {
   /* Create a new surface for this gfx mode */
-  if( !surface ) {
-    float scale = (float)gtkdisplay_current_size / image_scale;
-
-    surface =
-      cairo_image_surface_create_for_data( scaled_image,
-                                           CAIRO_FORMAT_RGB24,
-                                           scale * image_width,
-                                           scale * image_height,
-                                           scaled_pitch );
-  }
+  if( !surface ) ensure_appropriate_surface();
 
   /* Repaint the drawing area */
   cairo_set_source_surface( cr, surface, 0, 0 );
@@ -583,6 +585,9 @@ gtkdisplay_update_geometry( void )
 
   scale = scaler_get_scaling_factor( current_scaler );
 
+  hints = GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE |
+          GDK_HINT_BASE_SIZE | GDK_HINT_RESIZE_INC;
+
 #if GTK_CHECK_VERSION( 3, 0, 0 )
 
   /* Since GTK+ 3.20 it is intended that gtk_window_set_geometry_hints
@@ -597,14 +602,22 @@ gtkdisplay_update_geometry( void )
     extra_height += gtkstatusbar_get_height();
   }
 
-#else
+#ifdef GDK_WINDOWING_WAYLAND
+  /* We don't calculate the window size enough accurately on wayland
+     backend to force the window geometry (bug #367) */
+  GdkDisplay *display = gdk_display_get_default();
+
+  if( GDK_IS_WAYLAND_DISPLAY( display ) ) {
+    hints &= ~GDK_HINT_RESIZE_INC;
+  }
+#endif                /* #ifdef GDK_WINDOWING_WAYLAND */
+
+#else                 /* #if GTK_CHECK_VERSION( 3, 0, 0 ) */
 
   geometry_widget = gtkui_drawing_area;
 
 #endif                /* #if GTK_CHECK_VERSION( 3, 0, 0 ) */
 
-  hints = GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE |
-          GDK_HINT_BASE_SIZE | GDK_HINT_RESIZE_INC;
 
   geometry.min_width = DISPLAY_ASPECT_WIDTH;
   geometry.min_height = DISPLAY_SCREEN_HEIGHT + extra_height;
