@@ -51,8 +51,7 @@ int gtkkeyboard_release_all( GtkWidget *widget, GdkEvent *event,
  * Mouse routines (gtkmouse.c)
  */
 
-gboolean gtkmouse_position( GtkWidget*, GdkEventMotion*, gpointer );
-gboolean gtkmouse_button( GtkWidget*, GdkEventButton*, gpointer);
+void gtkmouse_init( void );
 
 /*
  * General user interface routines (gtkui.c)
@@ -118,11 +117,8 @@ GtkAccelGroup* gtkstock_create_close( GtkWidget *widget, GtkAccelGroup *accel,
 
 GtkWidget *gtkstock_dialog_new( const gchar *title, GCallback destroy );
 
-typedef PangoFontDescription *gtkui_font;
-
-int gtkui_get_monospaced_font( gtkui_font *font );
-void gtkui_free_font( gtkui_font font );
-void gtkui_set_font( GtkWidget *widget, gtkui_font font );
+int gtkui_get_monospaced_font( PangoFontDescription **font );
+void gtkui_free_font( PangoFontDescription *font );
 
 int gtkui_menubar_get_height( void );
 
