@@ -4,8 +4,6 @@
    Copyright (c) 2015 Stuart Brady
    Copyright (c) 2016 BogDan Vatra
 
-   $Id: debugger.c 5434 2016-05-01 04:22:45Z fredm $
-
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -55,7 +53,7 @@
 /* FIXME: delete whatever is not needed
 
 #include "machine.h"
-#include "memory.h"
+#include "memory_pages.h"
 
  */
 
