@@ -40,8 +40,8 @@ static LPCTSTR file_filter = TEXT(
 "*.mgtsnp;*.slt;*.sna;*.snapshot;*.snp;*.sp;*.szx;*.z80;*.zx-state;"
 "*.csw;*.ltp;*.pzx;*.raw;*.spc;*.sta;*.tzx;*.tap;*.wav;"
 "*.d40;*.d80;*.dsk;*.fdi;*.img;*.mgt;*.opd;*.opu;*.sad;*.scl;*.td0;*.trd;*.udi;"
-"*.dck;*.rom;*.hdf;*.mdr;*.rzx;"
-"*.png;*.pok;*.scr;*.svg;*.mlt"
+"*.dck;*.rom;*.hdf;*.mdr;*.fmf;*.rzx;"
+"*.bin;*.log;*.mlt;*.png;*.pok;*.scr;*.svg"
 #ifdef LIBSPECTRUM_SUPPORTS_ZLIB_COMPRESSION
 ";*.gz;*.zip"
 #endif
@@ -51,8 +51,8 @@ static LPCTSTR file_filter = TEXT(
 "\0"
 "All Files (*.*)\0"
 "*.*\0"
-"Auxiliary Files (*.scr;*.pok;*.png;*.svg;*.log;*.mlt)\0"
-"*.mlt;*.png;*.pok;*.scr;*.svg;*.log\0"
+"Auxiliary Files (*.scr;*.mlt;*.pok;*.png;*.svg;...)\0"
+"*.bin;*.log;*.mlt;*.png;*.pok;*.scr;*.svg\0"
 #ifdef LIBSPECTRUM_SUPPORTS_ZLIB_COMPRESSION
 "Compressed files (*.gz;*.zip;...)\0"
 "*.gz;*.zip"
@@ -69,6 +69,8 @@ static LPCTSTR file_filter = TEXT(
 "*.hdf\0"
 "Microdrive Files (*.mdr)\0"
 "*.mdr\0"
+"Movie Files (*.fmf)\0"
+"*.fmf\0"
 "Recording Files (*.rzx)\0"
 "*.rzx\0"
 "Snapshot Files (*.szx;*.z80;*.sna;...)\0"
