@@ -9,12 +9,14 @@ SETUP_CHECK( usource, usource_available )
 SETUP_CHECK( multiface, multiface_activated )
 SETUP_CHECK( if1p, if1_available )
 SETUP_CHECK( divide_early, settings_current.divide_enabled )
+SETUP_CHECK( divmmc_early, settings_current.divmmc_enabled )
 SETUP_CHECK( spectranet_page, spectranet_available && !settings_current.spectranet_disable )
 SETUP_NEXT( opcode_delay )
 SETUP_CHECK( evenm1, even_m1 )
 SETUP_NEXT( run_opcode )
 SETUP_CHECK( if1u, if1_available )
 SETUP_CHECK( divide_late, settings_current.divide_enabled )
+SETUP_CHECK( divmmc_late, settings_current.divmmc_enabled )
 SETUP_CHECK( opus, opus_available )
 SETUP_CHECK( spectranet_unpage, spectranet_available )
 SETUP_CHECK( z80_iff2_read, z80.iff2_read )
